==> webkit2gtk_2.19.5.orig.tar.xz: webkitgtk-2.19.5/Source/WTF/wtf/WTFAssertions.cpp <==
/*
 * Copyright (C) 2017-2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include <wtf/Bag.h>
#include <wtf/Poisoned.h>
#include <wtf/PoisonedUniquePtr.h>
#include <wtf/RefCountedArray.h>
#include <wtf/RefPtr.h>

namespace WTF {

namespace {
struct DummyStruct { };
const uint32_t dummyPoison = 0xffff;
}

#if ENABLE(POISON)
static_assert(!(makeConstExprPoison(1) >> 48), "poisoned bits should look like a pointer.");
static_assert(!(makeConstExprPoison(100) >> 48), "poisoned bits should look like a pointer.");
static_assert(!(makeConstExprPoison(1000) >> 48), "poisoned bits should look like a pointer.");
static_assert(!(makeConstExprPoison(10000) >> 48), "poisoned bits should look like a pointer.");
static_assert(!(makeConstExprPoison(1000000) >> 48), "poisoned bits should look like a pointer.");
static_assert(!(makeConstExprPoison(0xffffffff) >> 48), "poisoned bits should look like a pointer.");

static_assert((makeConstExprPoison(1) >> 32), "bits 32-47 of poisoned bits should not be not completely 0.");
static_assert((makeConstExprPoison(100) >> 32), "bits 32-47 of poisoned bits should not be not completely 0.");
static_assert((makeConstExprPoison(1000) >> 32), "bits 32-47 of poisoned bits should not be not completely 0.");
static_assert((makeConstExprPoison(10000) >> 32), "bits 32-47 of poisoned bits should not be not completely 0.");
static_assert((makeConstExprPoison(1000000) >> 32), "bits 32-47 of poisoned bits should not be not completely 0.");
static_assert((makeConstExprPoison(0xffffffff) >> 32), "bits 32-47 of poisoned bits should not be not completely 0.");

static_assert((makeConstExprPoison(1) & 0x4), "bit 2 should always be set.");
static_assert((makeConstExprPoison(100) & 0x4), "bit 2 should always be set.");
static_assert((makeConstExprPoison(1000) & 0x4), "bit 2 should always be set.");
static_assert((makeConstExprPoison(10000) & 0x4), "bit 2 should always be set.");
static_assert((makeConstExprPoison(1000000) & 0x4), "bit 2 should always be set.");
static_assert((makeConstExprPoison(0xffffffff) & 0x4), "bit 2 should always be set.");

static_assert(!(makeConstExprPoison(1) & 0x3), "ensure bottom 2 alignment bits are available for use as flag bits.");
static_assert(!(makeConstExprPoison(100) & 0x3), "ensure bottom 2 alignment bits are available for use as flag bits.");
static_assert(!(makeConstExprPoison(1000) & 0x3), "ensure bottom 2 alignment bits are available for use as flag bits.");
static_assert(!(makeConstExprPoison(10000) & 0x3), "ensure bottom 2 alignment bits are available for use as flag bits.");
static_assert(!(makeConstExprPoison(1000000) & 0x3), "ensure bottom 2 alignment bits are available for use as flag bits.");
static_assert(!(makeConstExprPoison(0xffffffff) & 0x3), "ensure bottom 2 alignment bits are available for use as flag bits.");
#endif // ENABLE(POISON)

static_assert(sizeof(Bag<DummyStruct>) == sizeof(void*), "");
static_assert(sizeof(PoisonedBag<dummyPoison, DummyStruct>) == sizeof(void*), "");

static_assert(sizeof(Ref<DummyStruct>) == sizeof(DummyStruct*), "");
static_assert(sizeof(PoisonedRef<dummyPoison, DummyStruct>) == sizeof(DummyStruct*), "");

static_assert(sizeof(RefPtr<DummyStruct>) == sizeof(DummyStruct*), "");
static_assert(sizeof(PoisonedRefPtr<dummyPoison, DummyStruct>) == sizeof(DummyStruct*), "");

static_assert(sizeof(PoisonedUniquePtr<dummyPoison, DummyStruct>) == sizeof(DummyStruct*), "");
static_assert(sizeof(PoisonedUniquePtr<dummyPoison, int[]>) == sizeof(int*), "");
static_assert(sizeof(PoisonedUniquePtr<dummyPoison, DummyStruct[]>) == sizeof(DummyStruct*), "");

static_assert(sizeof(RefCountedArray<DummyStruct>) == sizeof(void*), "");
static_assert(sizeof(PoisonedRefCountedArray<dummyPoison, DummyStruct>) == sizeof(void*), "");
    
} // namespace WTF

==> webkit2gtk_2.19.92.orig.tar.xz: webkitgtk-2.19.92/Source/WTF/wtf/WTFAssertions.cpp <==
/*
 * Copyright (C) 2017-2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include <wtf/Bag.h>
#include <wtf/Poisoned.h>
#include <wtf/PoisonedUniquePtr.h>
#include <wtf/RefCountedArray.h>
#include <wtf/RefPtr.h>

namespace WTF {

namespace {
struct DummyStruct { };
uintptr_t dummyPoison = 0;
}

static_assert(sizeof(Bag<DummyStruct>) == sizeof(void*), "");
static_assert(sizeof(PoisonedBag<Poison<dummyPoison>, DummyStruct>) == sizeof(void*), "");

static_assert(sizeof(Ref<DummyStruct>) == sizeof(DummyStruct*), "");
static_assert(sizeof(PoisonedRef<Poison<dummyPoison>, DummyStruct>) == sizeof(DummyStruct*), "");

static_assert(sizeof(RefPtr<DummyStruct>) == sizeof(DummyStruct*), "");
static_assert(sizeof(PoisonedRefPtr<Poison<dummyPoison>, DummyStruct>) == sizeof(DummyStruct*), "");

static_assert(sizeof(PoisonedUniquePtr<Poison<dummyPoison>, DummyStruct>) == sizeof(DummyStruct*), "");
static_assert(sizeof(PoisonedUniquePtr<Poison<dummyPoison>, int[]>) == sizeof(int*), "");
static_assert(sizeof(PoisonedUniquePtr<Poison<dummyPoison>, DummyStruct[]>) == sizeof(DummyStruct*), "");

static_assert(sizeof(RefCountedArray<DummyStruct>) == sizeof(void*), "");
static_assert(sizeof(PoisonedRefCountedArray<Poison<dummyPoison>, DummyStruct>) == sizeof(void*), "");
    
} // namespace WTF
